==> basicspace_0.03.zip: basicspace/doc/basicspace.R <==
###################################################
### chunk number 1: 
###################################################
#line 21 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
options(width=60)


###################################################
### chunk number 2: one
###################################################
#line 225 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
set.seed(1231)
library(basicspace)
N <- 1000
M <- 20
s <- 2
fraction.missing <- 0.3
E <- matrix(runif(N*M, min=-0.5, max=0.5),nrow=N,ncol=M)


###################################################
### chunk number 3: two
###################################################
#line 242 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
U <- matrix(runif(N*s),nrow=N,ncol=s)
D <- diag(seq(from=2.1, by=-0.2,length.out=s))
V.prime <- matrix(runif(s*M),nrow=s,ncol=M)
c <- rnorm(M)
Jn <- rep(1,N)


###################################################
### chunk number 4: three
###################################################
#line 253 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
X.true <- U %*% D %*% V.prime + Jn %o% c
X.0 <- X.true + E
Psi.true <- U %*% sqrt(D)
W.true <- t(V.prime) %*% sqrt(D)


###################################################
### chunk number 5: four
###################################################
#line 263 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
missing <- sample(1:(N*M), round(fraction.missing*N*M))
X.0[missing] <- 999


###################################################
### chunk number 6: five
###################################################
#line 272 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
rownames(X.0) <- paste("Legis", 1:N, sep="")
colnames(X.0) <- paste("V", 1:M, sep="")


###################################################
### chunk number 7: six
###################################################
#line 283 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
result <- blackbox(X.0,missing=c(999),verbose=TRUE,dims=2,minscale=8)
names(result)


###################################################
### chunk number 8: seven
###################################################
#line 303 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
par(mfrow=c(1,2))

plot(Psi.true[,1], result$individuals[[2]]$c1, xlim=c(0, 1.5), ylim=c(-0.65, 0.6),
pch=20,cex=0.4, cex.lab=1.6, bty="n",
xlab="True Psi, first dimension", ylab="Recovered Psi, first dimension")

plot(Psi.true[,2], result$individuals[[2]]$c2, xlim=c(0, 1.5), ylim=c(-0.65, 0.6),
pch=20,cex=0.4, cex.lab=1.6, bty="n",
xlab="True Psi, second dimension", ylab="Recovered Psi, second dimension")


###################################################
### chunk number 9: six
###################################################
#line 327 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
par(mfrow=c(1,2))

plot(W.true[,1], result$stimuli[[2]]$w1, ylim=c(1, 2.6),
pch=20, cex=1.5, cex.lab=1.6, bty="n",
xlab="True W, first dimension", ylab="Recovered W, first dimension")

plot(W.true[,2], result$stimuli[[2]]$w2, ylim=c(-2, 2),
pch=20,cex=1.5, cex.lab=1.6, bty="n",
xlab="True W, second dimension", ylab="Recovered W, second dimension")



###################################################
### chunk number 10: eight
###################################################
#line 347 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"

par(mfrow=c(1,1))

plot(c, result$stimuli[[2]]$c,
pch=20,cex=1.2, cex.lab=1.1, bty="n",
xlab="True C", ylab="Recovered C")


###################################################
### chunk number 11: nine
###################################################
#line 385 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"

W.hat <- cbind(result$stimuli[[2]]$w1, result$stimuli[[2]]$w2)
Psi.hat <- cbind(result$individuals[[2]]$c1, result$individuals[[2]]$c2)
X.hat <- Psi.hat %*% t(W.hat) + Jn %o% result$stimuli[[2]]$c

par(mfrow=c(1,2))

plot(X.true[missing], X.hat[missing],
pch=20,cex=0.4, cex.lab=1.2, bty="n",
xlab="True X, missing values", ylab="Recovered X, missing values")

plot(X.true[!(1:(N*M) %in% missing)], X.hat[!(1:(N*M) %in% missing)],
pch=20,cex=0.4, cex.lab=1.2, bty="n",
xlab="True X, nonmissing values", ylab="Recovered X, nonmissing values")


###################################################
### chunk number 12: ten
###################################################
#line 436 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
data(Issues1980)
Issues1980[1:10,1:4]


###################################################
### chunk number 13: eleven
###################################################
#line 445 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
Issues1980[Issues1980[,"abortion1"]==7,"abortion1"] <- 8
Issues1980[Issues1980[,"abortion2"]==7,"abortion2"] <- 8


###################################################
### chunk number 14: twelve
###################################################
#line 453 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
result <- blackbox(Issues1980,missing=c(0,8,9),verbose=FALSE,dims=3,minscale=8)


###################################################
### chunk number 15: thirteen
###################################################
#line 462 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
summary(result)


###################################################
### chunk number 16: fourteen
###################################################
#line 479 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
cor(result$individuals[[1]]$c1, Issues1980[,"libcon1"])


###################################################
### chunk number 17: blackbt
###################################################
#line 502 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
data(LC1980)
LCdat=LC1980[,-1]
LCdat[1:10,]
result <- blackbox_transpose(LCdat,missing=c(0,8,9),dims=3,minscale=5,verbose=TRUE)


###################################################
### chunk number 18: bbt
###################################################
#line 516 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"

par(mfrow=c(1,2))

plot(result)
plotcdf.blackbt(result)


###################################################
### chunk number 19: blackfinal
###################################################
#line 530 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
summary(result)


###################################################
### chunk number 20: aldmck
###################################################
#line 551 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
data(LC1980)
result <- aldmck(data=LC1980, polarity=2, respondent=1, missing=c(0,8,9),verbose=TRUE)
summary(result)


###################################################
### chunk number 21: aldmck_plot
###################################################
#line 561 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"

plot.aldmck(result)


###################################################
### chunk number 22: aldmck_boot
###################################################
#line 574 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
Ntrials <- 20
results <- vector("list", Ntrials)
for(i in 1:Ntrials) results[[i]] <- aldmck(data=LC1980[sample(1:nrow(LC1980),nrow(LC1980),replace=TRUE),], polarity=2, respondent=1, missing=c(0,8,9),verbose=FALSE)


###################################################
### chunk number 23: aldmck_MC
###################################################
#line 582 "d:/Rcompile/CRANpkg/local/2.12/basicspace/inst/doc/basicspace.Rnw"
Nstimuli <- 6
Nresp <- 500

Z_j <- rnorm(6)
Z_j <- (Z_j - mean(Z_j))/sd(Z_j)

respondent.sd <- runif(Nresp,min=0.3,max=0.9)
error_heteroskedastic <- matrix(NA,Nresp,Nstimuli)
for(i in 1:Nresp) error_heteroskedastic <- rnorm(Nstimuli,sd=respondent.sd)

w_i <- runif(Nresp,min=0,max=1)
c_i <- rnorm(Nresp)
Y_ij <- rep(1,500) %o%  Z_j
Y_ij <- Y_ij + error_heteroskedastic
Z_ij <-  1/w_i %o% rep(1,Nstimuli) * (Y_ij - c_i %o% rep(1,Nstimuli))

result <- aldmck(Z_ij,polarity=6,missing=c(999))

rank(Z_j)
rank(result$stimuli)

==> basicspace_0.05.zip: basicspace/doc/basicspace.R <==
### R code from vignette source 'basicspace.Rnw'

###################################################
### code chunk number 1: basicspace.Rnw:112-113
###################################################
options(width=60)


###################################################
### code chunk number 2: one
###################################################
set.seed(1231)
library(basicspace)
N <- 1000
M <- 20
s <- 2
fraction.missing <- 0.3
E <- matrix(runif(N*M, min=-0.5, max=0.5),nrow=N,ncol=M)


###################################################
### code chunk number 3: two
###################################################
U <- matrix(runif(N*s),nrow=N,ncol=s)
D <- diag(seq(from=2.1, by=-0.2,length.out=s))
V.prime <- matrix(runif(s*M),nrow=s,ncol=M)
c <- rnorm(M)
Jn <- rep(1,N)


###################################################
### code chunk number 4: three
###################################################
X.true <- U %*% D %*% V.prime + Jn %o% c
X.0 <- X.true + E
Psi.true <- U %*% sqrt(D)
W.true <- t(V.prime) %*% sqrt(D)


###################################################
### code chunk number 5: four
###################################################
missing <- sample(1:(N*M), round(fraction.missing*N*M))
X.0[missing] <- 999


###################################################
### code chunk number 6: five
###################################################
rownames(X.0) <- paste("Legis", 1:N, sep="")
colnames(X.0) <- paste("V", 1:M, sep="")


###################################################
### code chunk number 7: six
###################################################
result <- blackbox(X.0,missing=c(999),verbose=TRUE,dims=2,minscale=8)
names(result)


###################################################
### code chunk number 8: seven
###################################################
par(mfrow=c(1,2))

plot(Psi.true[,1], result$individuals[[2]]$c1, xlim=c(0, 1.5), ylim=c(-0.65, 0.6),
pch=20,cex=0.4, cex.lab=1.6, bty="n",
xlab="True Psi, first dimension", ylab="Recovered Psi, first dimension")

plot(Psi.true[,2], result$individuals[[2]]$c2, xlim=c(0, 1.5), ylim=c(-0.65, 0.6),
pch=20,cex=0.4, cex.lab=1.6, bty="n",
xlab="True Psi, second dimension", ylab="Recovered Psi, second dimension")


###################################################
### code chunk number 9: six
###################################################
par(mfrow=c(1,2))

plot(W.true[,1], result$stimuli[[2]]$w1, ylim=c(1, 2.6),
pch=20, cex=1.5, cex.lab=1.6, bty="n",
xlab="True W, first dimension", ylab="Recovered W, first dimension")

plot(W.true[,2], result$stimuli[[2]]$w2, ylim=c(-2, 2),
pch=20,cex=1.5, cex.lab=1.6, bty="n",
xlab="True W, second dimension", ylab="Recovered W, second dimension")



###################################################
### code chunk number 10: eight
###################################################

par(mfrow=c(1,1))

plot(c, result$stimuli[[2]]$c,
pch=20,cex=1.2, cex.lab=1.1, bty="n",
xlab="True C", ylab="Recovered C")


###################################################
### code chunk number 11: nine
###################################################

W.hat <- cbind(result$stimuli[[2]]$w1, result$stimuli[[2]]$w2)
Psi.hat <- cbind(result$individuals[[2]]$c1, result$individuals[[2]]$c2)
X.hat <- Psi.hat %*% t(W.hat) + Jn %o% result$stimuli[[2]]$c

par(mfrow=c(1,2))

plot(X.true[missing], X.hat[missing],
pch=20,cex=0.4, cex.lab=1.2, bty="n",
xlab="True X, missing values", ylab="Recovered X, missing values")

plot(X.true[!(1:(N*M) %in% missing)], X.hat[!(1:(N*M) %in% missing)],
pch=20,cex=0.4, cex.lab=1.2, bty="n",
xlab="True X, nonmissing values", ylab="Recovered X, nonmissing values")


###################################################
### code chunk number 12: ten
###################################################
data(Issues1980)
Issues1980[1:10,1:4]


###################################################
### code chunk number 13: eleven
###################################################
Issues1980[Issues1980[,"abortion1"]==7,"abortion1"] <- 8
Issues1980[Issues1980[,"abortion2"]==7,"abortion2"] <- 8


###################################################
### code chunk number 14: twelve
###################################################
result <- blackbox(Issues1980,missing=c(0,8,9),verbose=FALSE,dims=3,minscale=8)


###################################################
### code chunk number 15: thirteen
###################################################
summary(result)


###################################################
### code chunk number 16: fourteen
###################################################
cor(result$individuals[[1]]$c1, Issues1980[,"libcon1"])


###################################################
### code chunk number 17: blackbt
###################################################
data(LC1980)
LCdat=LC1980[,-1]
LCdat[1:10,]
result <- blackbox_transpose(LCdat,missing=c(0,8,9),dims=3,minscale=5,verbose=TRUE)


###################################################
### code chunk number 18: bbt
###################################################

par(mfrow=c(1,2))

plot(result)
plotcdf.blackbt(result)


###################################################
### code chunk number 19: blackfinal
###################################################
summary(result)


###################################################
### code chunk number 20: aldmck
###################################################
data(LC1980)
result <- aldmck(data=LC1980, polarity=2, respondent=1, missing=c(0,8,9),verbose=TRUE)
summary(result)


###################################################
### code chunk number 21: aldmck_plot
###################################################

plot.aldmck(result)


###################################################
### code chunk number 22: aldmck_boot
###################################################
Ntrials <- 20
results <- vector("list", Ntrials)
for(i in 1:Ntrials) results[[i]] <- aldmck(data=LC1980[sample(nrow(LC1980),nrow(LC1980),replace=TRUE),], polarity=2, respondent=1, missing=c(0,8,9),verbose=FALSE)


###################################################
### code chunk number 23: aldmck_MC
###################################################
Nstimuli <- 6
Nresp <- 500

Z_j <- rnorm(6)
Z_j <- (Z_j - mean(Z_j))/sd(Z_j)

respondent.sd <- runif(Nresp,min=0.3,max=0.9)
error_heteroskedastic <- matrix(NA,Nresp,Nstimuli)
for(i in 1:Nresp) error_heteroskedastic <- rnorm(Nstimuli,sd=respondent.sd)

w_i <- runif(Nresp,min=0,max=1)
c_i <- rnorm(Nresp)
Y_ij <- rep(1,500) %o%  Z_j
Y_ij <- Y_ij + error_heteroskedastic
Z_ij <-  1/w_i %o% rep(1,Nstimuli) * (Y_ij - c_i %o% rep(1,Nstimuli))

result <- aldmck(Z_ij,polarity=6,missing=c(999))

rank(Z_j)
rank(result$stimuli)
